require 'ruby_yacht'

RubyYacht.configure do
  project :apollo do
    # All the images and containers for this project will be prefixed with
    # 'apollo-'
    system_prefix :apollo
    
    # The repositories for the apps in this project will all be available at the
    # domain github.com.
    #
    # All repositories will be checked out over SSH, so you need to make sure
    # that the containers have SSH keys that can access the repository server.
    #
    # When the images are built, it will automatically copy the SSH key from
    # ~/.ssh/id_rsa into the containers.
    repository "github.com"
    
    # The secret key that we use for session information in the Rails apps.
    rails_secret_key_base 'abc'
    
    # The configuration for the database the app uses.
    # The apps will share a database called apollo
    mysql_database :apollo do
      # A database host of localhost tells ruby-yacht to build a database
      # container for the apps' local database.
      host "localhost"
      
      # The credentials for accessing the database.
      username "apollo"
      password "test"
    end
    
    rails_app :mars do
      # This app's repository is at github.com/brownleej/mars
      repository_name 'brownleej/mars'
      database_name :apollo
    end
    
    rails_app :saturn do
      # This app's repository is at github.com/brownleej/saturn
      repository_name 'brownleej/saturn'
      database_name :apollo
    end

    # This indicates that apollo.docker.local should serve requests to the mars
    # app.
    primary_app :mars

    nginx_web_server do
      # The web server will place the apps under 'apollo.docker.local'
      #
      # apollo.docker.local will point to a landing page with links to the apps,
      # and individual apps will be available at mars.apollo.docker.local and
      # saturn.apollo.docker.local
      domain "apollo.docker.local"
    end
  end

  # This is a second project that runs a different set of apps, with different
  # domains and a separate database.
  project :jupiter do
    system_prefix :jupiter
    repository "github.com"
    rails_secret_key_base 'abc'
    
    mysql_database :jupiter do
      # Because this host has a real domain, we will not build a database
      # container. The database at this host must be set up in advance with
      # the database and the credentials in this file.
      #
      # When the apps start, they will automatically run database migrations
      # against this database.
      host "db.test.com"

      username "jupiter"
      password "test"
    end
    
    rails_app :venus do
      repository_name 'brownleej/venus'
      database_name :jupiter
    end
    
    rails_app :saturn do
      repository_name 'brownleej/saturn'
      database_name :jupiter
    end

    # Because this project has no primary app, jupiter.docker.local will serve
    # an ad-hoc landing page with links to the individual apps.



    nginx_web_server do
      domain "jupiter.docker.local"

      # This project's web server will listen on port 8080, instead of the
      # default port 80.
      port 8080
    end
  end
end

RubyYacht::Runner.run

