#!/usr/bin/bash

# This script runs our tests in a docker container.
#
# This keeps the development dependencies isolated from other parts of the
# system.

EXISTING_IMAGE=`docker images | grep ruby-yacht-tests`
if [ -z "$EXISTING_IMAGE" ]; then
  if [ -f ~/.ssh/id_rsa ]; then
    cp ~/.ssh/id_rsa spec/docker
  else
    touch spec/docker/id_rsa
  fi
  docker build -t ruby-yacht-tests spec/docker
  rm spec/docker/id_rsa
fi

if [ -z $PRESERVE_IMAGES ]; then
  PRESERVE_IMAGES='0'
fi

EXTRA_FLAGS="$EXTRA_FLAGS -e PRESERVE_IMAGES=$PRESERVE_IMAGES"

if [ $PRESERVE_IMAGES -eq 1 ]; then
  EXTRA_FLAGS="$EXTRA_FLAGS -d"
  EXISTING_CONTAINER=`docker ps | grep ruby-yacht-tests`
else
  docker rm -f ruby-yacht-tests 1> /dev/null 2> /dev/null
  EXTRA_FLAGS="$EXTRA_FLAGS --rm"
  EXISTING_CONTAINER=""
fi

if [[ -n $VERBOSE_DOCKER && $VERBOSE_DOCKER -eq 1 ]]; then
  EXTRA_FLAGS="$EXTRA_FLAGS -e VERBOSE_DOCKER=1"
fi

if [ -z "$EXISTING_CONTAINER" ]; then
  docker run -it $EXTRA_FLAGS --privileged --name=ruby-yacht-tests -v $PWD:/var/code/ruby-yacht ruby-yacht-tests /var/docker/startup.bash $*
  RESULT=$?
fi

if [ $PRESERVE_IMAGES -eq 1 ]; then
  docker exec -it ruby-yacht-tests bash -c "bundle install --quiet; rspec $*"
  RESULT=$?
fi

exit $RESULT