require 'spec_helper'

RSpec.describe 'creating new project', :integration do
  include IntegrationHelpers  
  
  def run_command(command, environment: {}, capture_output: false)
    full_command = "#{command}"
    environment.each do |key, value|
      full_command = "#{key}=#{value} #{full_command}"
    end
    folder = File.basename(FileUtils.pwd)
    if capture_output
      `#{full_command}`
    else
      system "#{full_command} 1> ../#{folder}/log/integration_stdout.txt 2> ../#{folder}/log/integration_stderr.txt"
    end
  end

  before :all do
    run_command 'ruby_yacht new apollo ../apollo-config'
    run_command 'cd ../apollo-config; ruby run.rb build'
    wait_on_command_result 'curl -I -H Host:apollo.test.com localhost', contains: '200 OK'
  end

  after :all do
    IntegrationHelpers.clear_docker_containers
    system "docker rmi apollo 1> /dev/null 2> /dev/null"
    restore_hosts_file
    FileUtils.rm_rf '../apollo-config'
    FileUtils.rm_rf '../apollo'
  end

  let(:containers) { `docker ps | grep "apollo\\|jupiter"`.split("\n").collect { |line| line.split(/\s+/).last }.sort }

  it 'starts the containers' do
    expect(containers).to eq %w(apollo apollo-web)
  end
    
  it 'brings up the app servers' do
    results = `curl apollo.test.com 2>&1`
    expect(results).to include 'Ruby on Rails: Welcome aboard'
  end

  it 'checks out the apps to a local directory' do
    results = `ls ../apollo`.split("\n")
    expect(results).to include "app"
    expect(results).to include "Gemfile"
  end
end
  
