require 'spec_helper'

RSpec.describe 'project with no repository', :integration do
  include IntegrationHelpers  

  before :all do
    system 'docker rmi apollo-database 1> /dev/null 2> /dev/null'
    run_command 'build_images', environment: { NO_REPOSITORY: 1, CHECK_OUT_LOCALLY: 1, SKIP_DATABASE: 1 }
  end
  
  after :all do
    IntegrationHelpers.clear_docker_containers
  end

  describe 'building images' do
    it 'creates images for the app, dependencies, and web server' do
      expect(images).to eq ['apollo-mars', 'apollo-rails-app-dependencies', 'apollo-saturn', 'apollo-web']
    end

    it 'creates a fresh app in the app image' do
      results = run_command_in_docker :mars, 'ls /var/code'
      expect(results).to include 'app'
      expect(results).to include 'Gemfile'
    end
  end

  describe 'running containers' do
    before :all do
      run_command 'run_containers', environment: { NO_REPOSITORY: 1, CHECK_OUT_LOCALLY: 1, SKIP_DATABASE: 1 }

      wait_on_command_result 'curl -I -H Host:mars.apollo.johnbrownlee.com localhost', contains: '200 OK'
      wait_on_command_result 'curl -I -H Host:saturn.jupiter.johnbrownlee.com localhost', contains: '200 OK'
    end

    after :all do
      IntegrationHelpers.clear_docker_containers
      FileUtils.rm_rf '../mars'
      FileUtils.rm_rf '../saturn'
    end
    
    it 'starts all the containers' do
      expect(containers).to eq %w(apollo-mars apollo-saturn apollo-web)
    end
    
    it "brings up the app servers" do
      results = `curl -H Host:mars.apollo.johnbrownlee.com localhost 2>&1`
      expect(results).to include 'Ruby on Rails: Welcome aboard'
    end

    it "checks out the code to a local directory" do
      results = `ls ../mars`.split("\n")
      expect(results).to include "app"
      expect(results).to include "Gemfile"
    end
  end
end