require 'spec_helper'

RSpec.describe 'project with no database', :integration do
  include IntegrationHelpers  
  
  before :all do
    system "docker rmi apollo-database 1> /dev/null 2> /dev/null"
    run_command 'build_images', environment: { SKIP_DATABASE: 1 }
  end

  describe 'building images' do
    it "does not build a database image" do
      expect(images).to eq ['apollo-mars', 'apollo-rails-app-dependencies', 'apollo-saturn', 'apollo-web']
    end

    it 'does not install mysql on the app servers' do
      results = run_command_in_docker :mars, 'which mysql'
      expect(results).to eq ''
    end
  end

  describe 'running containers' do
    before :all do
      run_command 'run_containers', environment: { SKIP_DATABASE: 1 }
    end
    
    after :all do
      IntegrationHelpers.clear_docker_containers
    end
    
    it "starts all the containers except the database server" do
      expect(containers).to eq %w(apollo-mars apollo-saturn apollo-web)
    end
    
    it "allows the apps to use their local sqlite databases" do
      results = `docker exec -it apollo-mars rails r 'puts User.count'`
      expect(results).to eq "0\r\n"
    end
  end

  describe 'starting services' do
    before do
      IntegrationHelpers.image_names.each do |image|
        system "docker stop #{image} 1> /dev/null 2> /dev/null"
      end

      run_command 'run_containers', environment: { SKIP_DATABASE: 1 }
      run_command 'services start', environment: { SKIP_DATABASE: 1 }
    end
    
    it 'does not start the database image' do
      results = `docker ps | grep apollo`.split("\n")
      results = results.collect { |line| line.split(/\s+/).last }
      results.sort!
      expect(results).to eq %w(apollo-mars apollo-saturn apollo-web)
    end
  end
end