require 'spec_helper'

RSpec.describe 'project with HTTPS repository', :integration do
  include IntegrationHelpers  

  before :all do
    run_command 'build_images', environment: { HTTPS_REPOSITORY: 1 }
  end
  
  after :all do
    IntegrationHelpers.clear_docker_containers
  end

  describe 'building images' do
    it 'creates images for the app, dependencies, database, and web server' do
      expect(images).to eq ['apollo-database', 'apollo-mars', 'apollo-rails-app-dependencies', 'apollo-saturn', 'apollo-web']
    end

    it 'puts the HTTPS repository in the REPOSITORY_HOST environment variable' do
      results = run_command_in_docker :mars, "bash -c 'echo $REPOSITORY_HOST'"
      expect(results).to eq "https://github.com\n"
    end

    it 'checks out the app in the app image' do
      results = run_command_in_docker :mars, 'ls /var/code/app/models'
      expect(results).to include 'user.rb'
      expect(results).to include 'post.rb'
    end
  end

  describe 'running containers' do
    before :all do
      run_command 'run_containers', environment: { HTTPS_REPOSITORY: 1 }
      
      wait_on_command_success 'curl localhost'
      wait_on_command_result 'curl -I -H Host:mars.apollo.johnbrownlee.com localhost', contains: '200 OK'
      wait_on_command_result 'curl -I -H Host:saturn.apollo.johnbrownlee.com localhost', contains: '200 OK'
    end
    
    it "starts all the containers" do
      expect(containers).to eq %w(apollo-database apollo-mars apollo-saturn apollo-web)
    end
    
    it "makes the app servers accessible from the host machine" do
      results = `curl -H Host:mars.apollo.johnbrownlee.com localhost/users 2>&1`
      expect(results).to include 'test_user@mars.apollo.johnbrownlee.com'

      results = `curl -H Host:saturn.apollo.johnbrownlee.com localhost 2>&1`
      expect(results).to include 'Welcome to Saturn'
    end
  end
end