require 'spec_helper'

RSpec.describe 'project with a local checkout folder', :integration do
  include IntegrationHelpers

  before :all do
    run_command 'build_images', environment: { CHECK_OUT_LOCALLY: 1 }
  end
    
  after :all do
    IntegrationHelpers.clear_docker_containers
    IntegrationHelpers.clear_checkout_folders
  end
  
  describe 'running containers' do
    before :all do
      run_command 'run_containers', environment: { CHECK_OUT_LOCALLY: 1 }
    end
    
    it "starts all the containers" do
      expect(containers).to eq %w(apollo-database apollo-mars apollo-saturn apollo-web)
    end
    
    it "checks out the code to a local directory" do
      results = `ls ..`.split("\n")
      expect(results).to include "mars"
      expect(results).to include "saturn"

      results = `ls ../mars`.split("\n")
      expect(results).to include 'app'
      expect(results).to include 'Gemfile'
    end
  end

  describe 'checking out new branches' do
    before :all do
      run_command 'run_containers', environment: { CHECK_OUT_LOCALLY: 1 }
      run_command 'checkout mars checkout-test-branch', environment: { CHECK_OUT_LOCALLY: 1 }
    end
    
    it "updates the code from the server" do
      results = `ls ../mars/app/controllers`.split("\n")
      expect(results).to include 'users_controller.rb'
      expect(results).to include 'posts_controller.rb'
    end
    
    after :all do
      IntegrationHelpers.clear_docker_containers
      IntegrationHelpers.clear_checkout_folders
    end
  end
end