require 'spec_helper'

RSpec.describe 'project with a multiple projects', :integration do
  include IntegrationHelpers

  before :all do
    run_command 'build_images', environment: { CREATE_SECOND_PROJECT: 1 }
  end

  after :all do
    IntegrationHelpers.clear_docker_containers
    IntegrationHelpers.image_names.select { |name| name =~ /jupiter/ }.each do |name|
      `docker rmi #{name} 1> /dev/null`
    end
  end

  describe "running containers" do
    before :all do
      run_command 'run_containers', environment: { CREATE_SECOND_PROJECT: 1 }
      wait_on_command_result 'curl -I -H Host:mars.apollo.johnbrownlee.com localhost', contains: '200 OK'
      wait_on_command_result 'curl -I -H Host:saturn.jupiter.johnbrownlee.com localhost:8080', contains: '200 OK'
    end
    
    it "starts all the containers" do
      expect(containers).to eq %w(apollo-database apollo-mars apollo-saturn apollo-web jupiter-database jupiter-saturn jupiter-web)
    end
    
    it 'makes the apps for both projects accessible' do
      results = `curl -H Host:mars.apollo.johnbrownlee.com localhost/users 2>&1`
      expect(results).to include 'test_user@mars.apollo.johnbrownlee.com'

      results = `curl -H Host:saturn.jupiter.johnbrownlee.com localhost:8080 2>&1`
      expect(results).to include 'Welcome to Saturn'
    end

    it 'makes the apps accessible within projects' do
      results = `docker exec -it apollo-mars curl apollo-saturn:8080`
      expect(results).to include 'Welcome to Saturn'
    end

    it 'does not make the apps accessible from one project to another' do
      results = `docker exec -it apollo-mars curl jupiter-saturn:8080`
      expect(results).to include 'Could not resolve host: jupiter-saturn'
    end
  end
end