require 'spec_helper'

RSpec.describe 'project with an app with the same name', :integration do
  include IntegrationHelpers

  before :all do
    system "docker rmi apollo-mars 1> /dev/null 2> /dev/null"
    run_command 'build_images', environment: { CREATE_TITULAR_APP: 1 }
  end

  after :all do
    system "docker rmi apollo 1> /dev/null 2> /dev/null"
  end

  describe "building images" do
    it "creates an image with the same name as the project" do
      expect(images).to eq ['apollo', 'apollo-database', 'apollo-rails-app-dependencies', 'apollo-saturn', 'apollo-web']
    end 
    
    it "checks out the app onto the image" do
      results = `docker run --rm apollo ls /var/code/app/models`
      expect(results).to include 'user.rb'
      expect(results).to include 'post.rb'
    end 
  end

  describe "running containers" do
    before :all do
      run_command 'run_containers', environment: { CREATE_TITULAR_APP: 1 }
      wait_on_command_result 'curl -I -H Host:apollo.johnbrownlee.com localhost', contains: '200 OK'
      wait_on_command_result 'curl -I -H Host:saturn.apollo.johnbrownlee.com localhost', contains: '200 OK'
    end
    
    after :all do
      system "docker rm -f apollo 1> /dev/null"
      IntegrationHelpers.clear_docker_containers
    end
    
    it "starts all the containers" do
      expect(containers).to eq %w(apollo apollo-database apollo-saturn apollo-web)
    end
    
    it "makes the web server accessible from the host machine" do
      results = `curl -H Host:apollo.johnbrownlee.com localhost/users 2>&1`
      expect(results).to include 'test_user@mars.apollo.johnbrownlee.com'
    end

    it "makes the secondary app accessible" do
      results = `curl -H Host:saturn.apollo.johnbrownlee.com localhost 2>&1`
      expect(results).to include 'Welcome to Saturn'
    end
  end
end
