require 'ruby_yacht'

RubyYacht.configure do
  add_local_config File.join(File.dirname(__FILE__), '..', 'fixtures', 'local_config.yml')
end

RubyYacht.configure do
  project :apollo do
    system_prefix :apollo
    repository 'github.com'
    if ENV['HTTPS_REPOSITORY'] == '1'
      repository_protocol :https
    end
    
    rails_secret_key_base 'c330d739b502b4c43f4a850c592798243c5e92b1828b4e1e69de764fbdf8e733e0165241c67a76f34a9a46b10d27960fa288149ac662ea6bd9408fdb766aea39'

    if ENV['USE_LOCAL_CONFIG'] == '1'
      copy_local_config :rails_environment
    end
    
    if ENV['CHECK_OUT_LOCALLY'] == '1'
      check_out_locally
    end
    
    unless ENV['SKIP_DATABASE'] == '1'
      mysql_database :apollo do
        username 'apollo'
        password 'testpass'
        host 'localhost'
        
        if ENV['USE_LOCAL_CONFIG'] == '1'
          copy_local_config :username, :password, :host, from: 'database'
        end
        
        if ENV['USE_NONSTANDARD_MYSQL_PORT'] == '1'
          port 3333
        end
      end
    end
    
    first_app_name = ENV['CREATE_TITULAR_APP'] == '1' ? :apollo : :mars
    rails_app first_app_name do
      repository_name 'brownleej/ruby-yacht-mars' unless ENV['NO_REPOSITORY'] == '1'
      unless ENV['SKIP_DATABASE'] == '1'
        database_name :apollo
      end
    end
    
    rails_app :saturn do
      repository_name 'brownleej/ruby-yacht-saturn' unless ENV['NO_REPOSITORY'] == '1'
      unless ENV['SKIP_DATABASE'] == '1'
        database_name :apollo
      end
    end

    nginx_web_server do
      domain 'apollo.johnbrownlee.com'
    end

    if ENV['CONFIGURE_DNS'] == '1'
      dns_server do
        server '4.4.4.4'
        server '8.8.8.8'

        search_domain 'dns1.test.com'
        search_domain 'dns2.test.com'
      end
    end

    if ENV['USE_PRODUCTION_ENVIRONMENT'] == '1'
      rails_environment 'production'
      rails_excluded_gem_groups %w(development test)
    end

    if ENV['CREATE_PRIMARY_APP'] == '1'
      primary_app :mars
    end
  end

  if ENV['CREATE_SECOND_PROJECT'] == '1'
    project :jupiter do
      system_prefix :jupiter
      repository 'github.com'
      rails_secret_key_base 'c330d739b502b4c43f4a850c592798243c5e92b1828b4e1e69de764fbdf8e733e0165241c67a76f34a9a46b10d27960fa288149ac662ea6bd9408fdb766aea39'
    
      unless ENV['SKIP_DATABASE'] == '1'
        mysql_database :jupiter do
          username 'jupiter'
          password 'testpass'
          host 'localhost'
        end
      end
      
      rails_app :saturn do
        repository_name 'brownleej/ruby-yacht-saturn'
        unless ENV['SKIP_DATABASE'] == '1'
          database_name :jupiter
        end
      end

      nginx_web_server do
        domain 'jupiter.johnbrownlee.com'
        port   8080
      end
    end
  end
end

RubyYacht::Runner.run