require 'spec_helper'

describe RubyYacht::Plugins::MySQL do
  before do
    RubyYacht.configuration.clear
    described_class.load
  end
  
  it "adds MySQL to the app type list" do
    expect(RubyYacht.configuration.server_types.map(&:name)).to include :mysql
  end

  it "sets a default for port of 3306" do
    RubyYacht.configure do
      project :apollo do
        system_prefix :apollo
        repository "github.com"
        
        mysql_database :apollo do
          host "localhost"
          username "apollo"
          password "test"
        end
      end
    end

    expect(RubyYacht.configuration.projects.first.databases.first.port).to eq 3306
  end

  describe "building images" do
    subject { RubyYacht::Runner::BuildImages.new }
    include DockerCommandSpec

    before do
      RubyYacht.configuration.clear
      described_class.load

      RubyYacht.configure do
        server_type :generic do
          container_type :app
          baseline_image :ubuntu
        end
      end

      RubyYacht.configure do
        project :apollo do
          system_prefix :apollo
          repository "github.com"
          
          mysql_database :apollo do
            host "localhost"
            username "apollo"
            password "test"
            port 3306
          end

          generic_app :mars do
            repository_name 'brownleej/mars'
            database_name :apollo
          end
        end
      end
    end

    it "copies the scripts to the docker folder" do
      docker.expect("build -t apollo-database tmp") do
        files = Dir[File.join("tmp", "*")].sort
        expect(files).to eq ['tmp/Dockerfile', 'tmp/Dockerfile.erb', 'tmp/checkout.bash', 'tmp/setup.bash', 'tmp/startup.bash', 'tmp/startup.bash.erb']
      end
      subject.run
    end

    it "builds the dockerfile for a MySQL database" do
      docker.expect("build -t apollo-database tmp") do
        dockerfile = File.read(File.join('tmp', 'Dockerfile'))
        expected = File.read(File.join('spec', 'fixtures', 'database-dockerfile-mysql'))
        expect(dockerfile).to eq expected
      end
      subject.run
    end

    it "builds the startup script for a MySQL database" do
      docker.expect("build -t apollo-database tmp") do
        startup_file = File.read(File.join('tmp', 'startup.bash'))
        expected = File.read(File.join('spec', 'fixtures', 'database-startup-mysql'))
        expect(startup_file).to eq expected
      end
      subject.run
    end
  end
end