require 'spec_helper'

describe RubyYacht::Plugins::Nginx do
  before do
    RubyYacht.configuration.clear
    RubyYacht::Plugins::Nginx.load
  end

  it 'creates a server type called nginx' do
    server_type = RubyYacht.configuration.server_types.first
    expect(server_type.name).to eq :nginx
    expect(server_type.container_type).to eq :web
  end

  describe "building images" do
    subject { RubyYacht::Runner::BuildImages.new }
    include DockerCommandSpec

    before do
      RubyYacht.configuration.clear
      described_class.load

      RubyYacht.configure do
        server_type :generic do
          container_type :app
          baseline_image 'ubuntu'
        end
      end

      RubyYacht.configure do
        project :apollo do
          system_prefix :apollo
          repository "github.com"
          
          generic_app :mars
          generic_app :saturn

          nginx_web_server do
            domain 'apollo.test.com'
          end 
        end
      end
    end
    
    it "builds all the images for the project" do
      docker.fail_unexpected_commands!
      docker.expect "network create apollo 2> /dev/null"
      docker.expect "build -t apollo-generic-app-dependencies tmp"
      docker.expect "build -t apollo-mars tmp"
      docker.expect "build -t apollo-saturn tmp"
      docker.expect "build -t apollo-web tmp"
      subject.run
    end
    
    it "generates the dockerfiles for the web server" do
      docker.expect "build -t apollo-web tmp" do
        files = Dir[File.join("tmp", "*")].sort
        expect(files).to eq ['tmp/Dockerfile', 'tmp/Dockerfile.erb', 'tmp/add_app.rb', 'tmp/add_project.rb', 'tmp/app_config.erb', 'tmp/index.html.erb', 'tmp/index_config.erb']
        dockerfile = File.read(File.join('tmp', 'Dockerfile'))
        expected = File.read(File.join('spec', 'fixtures', 'web-dockerfile-nginx'))
        expect(dockerfile).to eq expected
      end
      subject.run
    end
  end
end