require 'spec_helper'

describe RubyYacht::Runner::Build do
  include DockerCommandSpec
  
  describe "command information" do
    specify { expect(described_class.command).to eq 'build' }
    specify { expect(described_class.description).to eq 'Build images and run containers' }
  end
  
  describe "run behavior" do
    let(:commands) { [double, double, double] }
    
    before do
      allow(RubyYacht::Runner::BuildImages).to receive(:new).and_return commands[0]
      allow(RubyYacht::Runner::RunContainers).to receive(:new).and_return commands[1]
      allow(RubyYacht::Runner::UpdateHosts).to receive(:new).and_return commands[2]
      
      commands.each { |command| allow(command).to receive(:run).and_return(true) }
    end
    
    context "with successes from all commands" do
      it "builds the images, runs the containers, and update the hosts" do
        subject.run
        expect(commands[0]).to have_received(:run) 
        expect(commands[1]).to have_received(:run)
        expect(commands[2]).to have_received(:run)     
      end
      
      it "returns true" do
        expect(subject.run).to be_truthy
      end
    end
    
    context "with an error building the images" do
      before do
        allow(commands[0]).to receive(:run).and_return false
      end
      
      it "builds the images, but does not runs the containers or update the hosts" do
        subject.run
        expect(commands[0]).to have_received(:run) 
        expect(commands[1]).not_to have_received(:run)
        expect(commands[2]).not_to have_received(:run)     
      end
      
      it "returns false" do
        expect(subject.run).to be_falsey
      end
    end
    
    context "an error running containers" do
      before do
        allow(commands[1]).to receive(:run).and_return false
      end
      
      it "builds the images and runs the containers, but does not update the hosts" do
        subject.run
        expect(commands[0]).to have_received(:run) 
        expect(commands[1]).to have_received(:run)
        expect(commands[2]).not_to have_received(:run)     
      end
      
      it "returns false" do
        expect(subject.run).to be_falsey
      end
    end
    
    context "with an error updating hosts" do
      before do
        allow(commands[2]).to receive(:run).and_return false
      end
      
      it "builds the images, runs the containers, and update the hosts" do
        subject.run
        expect(commands[0]).to have_received(:run) 
        expect(commands[1]).to have_received(:run)
        expect(commands[2]).to have_received(:run)     
      end
      
      it "returns true" do
        expect(subject.run).to be_falsey
      end
    end
  end
end
