require 'spec_helper'

describe RubyYacht::Runner::CreateNewProject do
  include DockerCommandSpec
  
  describe 'command information' do
    specify { expect(described_class.command).to eq 'new' }
    specify { expect(described_class.description).to eq 'Create a new ruby-yacht project' }
    
    describe 'command-line parsing' do
      let(:options) { subject.option_parser }
      
      it 'gives a summary in the banner' do
        expect(options.banner).to eq "Usage: rspec new [PROJECT] [DIRECTORY]\n\nCreate a new ruby-yacht project"
      end

      it 'takes the project and directory from the command line' do
        subject.parse_positional_arguments(['apollo', 'apollo-config'])
        expect(subject.project).to eq 'apollo'
        expect(subject.directory).to eq 'apollo-config'
      end
    end
  end
  
  describe "run behavior" do
    before do
      subject.project = 'apollo'
      subject.directory = 'apollo-config'
    end

    after do
      FileUtils.rm_rf('apollo-config')
    end

    it 'creates a project file' do
      subject.run
      path = './apollo-config/run.rb'
      expect(File.exist?(path)).to be_truthy
      contents = File.read(path)
      expected = File.read('spec/fixtures/apollo-new-project-config')
      expect(contents).to eq expected
    end

    it 'logs a message about the results' do
      subject.run
      expect(@log_entries).to eq [
        'Your project has been created in apollo-config/run.rb.',
        'You can go to apollo-config and run `ruby run.rb build` to create your docker containers.',
        'Your initial app will be created in the apollo directory.'
      ]
    end

    it "returns true" do
      expect(subject.run).to be_truthy
    end
    
    context 'with no project' do
      before do
        subject.project = nil
      end

      it 'logs an error' do
        subject.run
        expect(@log_entries).to eq [
          'You must provide a project',
          'Run rspec help new for more information'
        ]
      end
      
      it 'returns false' do
        expect(subject.run).to be_falsey
      end
    end
    
    context 'with no directory' do
      before do
        subject.directory = nil
      end
      
      it 'logs an error' do
        subject.run
        expect(@log_entries).to eq [
          'You must provide a directory',
          'Run rspec help new for more information'
        ]
      end
      
      it 'returns false' do
        expect(subject.run).to be_falsey
      end
    end
  end
end
