require 'spec_helper'

describe RubyYacht::Runner::Help do
  include DockerCommandSpec
  
  describe "command information" do
    specify { expect(described_class.command).to eq 'help' }
    specify { expect(described_class.description).to eq 'Get information on available commands' }
    
    describe "option_parser" do
      it "provides the usage information" do
        options = subject.option_parser
        expect(options.banner).to eq "Usage: rspec help [command]\n\nGet information on available commands"
      end
    end
    
    describe "parse_positional_arguments" do
      it "takes the command from the arguments" do
        subject.parse_positional_arguments(%w(checkout foo))
        expect(subject.command).to eq 'checkout'
      end
    end
  end
  
  describe "run behavior" do
    before do
      RubyYacht::Runner.load_default_commands
    end
    
    context "with no command" do
      it "prints the available commands" do
        subject.run
        expected = ["Available commands: \n\n"]
        expected += RubyYacht::Runner.commands.map { |c| "#{c.command}: #{c.description}" }
        expected << "\nRun rspec help [command] for more information on a command"
        expect(@log_entries).to eq expected
      end
      
      it "returns true" do
        expect(subject.run).to be_truthy
      end
    end
    
    context "with a command" do
      before do
        subject.command = 'checkout'
      end
      
      it "prints the usage information for the command" do
        subject.run
        expect(@log_entries).to eq [RubyYacht::Runner::Checkout.new.option_parser.to_s]
      end
      
      it "returns true" do
        expect(subject.run).to be_truthy
      end
    end
    
    context "with an invalid command" do
      before do
        subject.command = 'foo'
      end
      
      it "prints an error" do
        subject.run
        expect(@log_entries).to eq [
          "Command not available: foo",
          "Run rspec help for more options"
        ]
      end
      
      it "returns false" do
        expect(subject.run).to be_falsey
      end
    end
  end
end
