require 'spec_helper'

describe RubyYacht::Runner::Implode do
  include DockerCommandSpec
  
  describe "command information" do
    specify { expect(described_class.command).to eq 'implode' }
    specify { expect(described_class.description).to eq 'Destroy your local environment' }
  end
  
  describe "run behavior" do
    before do
      allow(subject).to receive(:backtick).with('docker ps -a | grep apollo').and_return("123 up apollo-mars\n456 up apollo-saturn\n789 apollo-venus")
      allow(subject).to receive(:backtick).with('docker images | grep apollo').and_return("apollo-app-dependencies 1GB\napollo-mars 1GB")
      allow(subject).to receive(:backtick).with('docker ps -a | grep jupiter').and_return("abc up jupiter-saturn")
      allow(subject).to receive(:backtick).with('docker images | grep jupiter').and_return("jupiter-app-dependencies 1GB\njupiter-mars 1GB")
      
      allow(subject).to receive(:backtick).with('docker images -q --filter dangling=true').and_return("111\n222")
    end
    
    it "removes all the containers and images" do
      docker.fail_unexpected_commands!
      docker.expect 'rm -f 123'
      docker.expect 'rm -f 456'
      docker.expect 'rm -f 789'
      docker.expect 'rmi apollo-app-dependencies'
      docker.expect 'rmi apollo-mars'
      docker.expect 'rmi 111'
      docker.expect 'rmi 222'
      subject.run
    end
    
    it "returns true" do
      expect(subject.run).to be_truthy
    end
    
    context "with a second project" do
      before do
        RubyYacht.configure_second_test_project
      end
      
      it "removes containers and images for both projects" do
        docker.fail_unexpected_commands!
        docker.expect 'rm -f 123'
        docker.expect 'rm -f 456'
        docker.expect 'rm -f 789'
        docker.expect 'rmi apollo-app-dependencies'
        docker.expect 'rmi apollo-mars'
        docker.expect 'rm -f abc'
        docker.expect 'rmi jupiter-app-dependencies'
        docker.expect 'rmi jupiter-mars'
        docker.expect 'rmi 111'
        docker.expect 'rmi 222'
        subject.run
      end
      
      it "returns true" do
        expect(subject.run).to be_truthy
      end
    end
  end
end
