module RubyYacht
  def self.configure_server_types
    RubyYacht.configure do
      server_type :generic do
        container_type :app
        baseline_image 'ubuntu'
      end

      server_type :debian do
        container_type :app
        baseline_image 'debian'
      end

      server_type :nginx do
        container_type :web
        baseline_image 'ubuntu'
      end
    end

    RubyYacht.configure do
      during :startup do
        app_server_type :generic
        container_type :app
        command '/var/docker/start_app.bash'
      end
    end
  end
  
  def self.configure_test_project
    RubyYacht.configuration.clear
    self.configure_server_types
    RubyYacht.configure do
      project :apollo do
        system_prefix :apollo
        repository "github.com"
        
        generic_app :mars do
          repository_name 'brownleej/mars'
        end
        
        debian_app :saturn do
          repository_name 'brownleej/saturn'
        end

        nginx_web_server :nginx do
          domain 'apollo.test.com'
        end
      end
    end
  end
  
  def self.configure_second_test_project
    RubyYacht.configure do
      project :jupiter do
        system_prefix :jupiter
        repository "github.com"
        
        debian_app :venus do
          repository_name 'brownleej/venus'
        end
        
        debian_app :saturn do
          repository_name 'brownleej/saturn'
        end

        nginx_web_server do
          domain 'jupiter.test.com'
        end
      end
    end
  end
end